==> haskell-ral-0.2.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ral.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ral
version:              0.2.1
visibility:           public
id:                   ral-0.2.1-8sJ9jsU4biDK7B3o2tm3h9
key:                  ral-0.2.1-8sJ9jsU4biDK7B3o2tm3h9
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Random access lists
description:
    This package provides ordinary random access list, '\''RAList'\'', and also
    a length indexed variant, '\''RAVec'\''.

    The data structure allows fast cons-operation (like ordinary list) but also fast random access (like non-functional arrays).

    For @lens@ or @optics@ support see [ral-lens](https://hackage.haskell.org/package/ral-lens) and [ral-optics](https://hackage.haskell.org/package/ral-optics) packages respectively.

    === Similar packages

    These packages don'\''t provide length-indexed variants, and their '\''RAList'\'' has
    opaque structure.

    * https://hackage.haskell.org/package/ralist
    * https://hackage.haskell.org/package/random-access-list

category:             Data, Dependent Types, Singletons
abi:                  cfcc4c269d16a4a47846d325e4bdb108
exposed:              True
exposed-modules:
    Data.RAList Data.RAList.NonEmpty Data.RAList.Tree Data.RAVec
    Data.RAVec.NonEmpty Data.RAVec.Tree Data.RAVec.Tree.DF

hidden-modules:
    Data.RAList.Internal Data.RAList.NonEmpty.Internal
    Data.RAList.Tree.Internal TrustworthyCompat

import-dirs:          /usr/lib/ghc-9.0.2/site-local/ral-0.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ral-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ral
hs-libraries:         HSral-0.2.1-8sJ9jsU4biDK7B3o2tm3h9
depends:
    QuickCheck-2.14.2-2d1sNWCQrBtBwhjNiSfZuE
    adjunctions-4.4-KIshoC7T2Xm6unrUYLcI7D base-4.15.1.0
    bin-0.1.2-Ftw5R8Eoj5j62txEzxcKxd boring-0.2-AywtoMK07vg9Z9Ocyuk3Wm
    deepseq-1.4.5.0 distributive-0.6.2.1-CeMrxaxhyMt37Xl63aBbG2
    fin-0.2.1-ifWahwmCb9KN7W2zzFRyw
    hashable-1.4.0.0-Ad25gOPS1LBBwFTwmctznB
    indexed-traversable-0.1.2-55rCITp0bj2K4TSTU28RrG
    semigroupoids-5.3.7-LNx6FZQ6yl1Ls9mIgv9Bbs

haddock-interfaces:   /usr/share/doc/haskell-ral/html/ral.haddock
haddock-html:         /usr/share/doc/haskell-ral/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ral-0.2.1-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ral.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ral
version:              0.2.1
visibility:           public
id:                   ral-0.2.1-IPHiCE3abeZTrlo6zRbAS
key:                  ral-0.2.1-IPHiCE3abeZTrlo6zRbAS
license:              GPL-2.0-or-later
copyright:            (c) 2019-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Random access lists
description:
    This package provides ordinary random access list, '\''RAList'\'', and also
    a length indexed variant, '\''RAVec'\''.

    The data structure allows fast cons-operation (like ordinary list) but also fast random access (like non-functional arrays).

    For @lens@ or @optics@ support see [ral-lens](https://hackage.haskell.org/package/ral-lens) and [ral-optics](https://hackage.haskell.org/package/ral-optics) packages respectively.

    === Similar packages

    These packages don'\''t provide length-indexed variants, and their '\''RAList'\'' has
    opaque structure.

    * https://hackage.haskell.org/package/ralist
    * https://hackage.haskell.org/package/random-access-list

category:             Data, Dependent Types, Singletons
abi:                  c5078fb637a8a2f07e7fd97a96df8c37
exposed:              True
exposed-modules:
    Data.RAList Data.RAList.NonEmpty Data.RAList.Tree Data.RAVec
    Data.RAVec.NonEmpty Data.RAVec.Tree Data.RAVec.Tree.DF

hidden-modules:
    Data.RAList.Internal Data.RAList.NonEmpty.Internal
    Data.RAList.Tree.Internal TrustworthyCompat

import-dirs:          /usr/lib/ghc-9.0.2/site-local/ral-0.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ral-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ral
hs-libraries:         HSral-0.2.1-IPHiCE3abeZTrlo6zRbAS
depends:
    QuickCheck-2.14.2-CKku5U4XaTZ1OrrQj3RQZM
    adjunctions-4.4.1-BNto8NlwMTjDie6EmELuN3 base-4.15.1.0
    bin-0.1.2-EYaREPnopwl4EKGj556IYd boring-0.2-AywtoMK07vg9Z9Ocyuk3Wm
    deepseq-1.4.5.0 distributive-0.6.2.1-LjLOjhTdX2eFe8TE76iQFb
    fin-0.2.1-47XkfgtwwmW4wbvLXHT0FZ
    hashable-1.4.0.2-A7cEvE0oiq92I0kqqbT0NC
    indexed-traversable-0.1.2-55rCITp0bj2K4TSTU28RrG
    semigroupoids-5.3.7-5Xe3mmrUnJFL7evkYKNqog

haddock-interfaces:   /usr/share/doc/haskell-ral/html/ral.haddock
haddock-html:         /usr/share/doc/haskell-ral/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
